# Generated by Django 2.0.2 on 2018-02-20 22:54

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('topology', '0003_link_status_and_openvpn_parser'),
    ]

    operations = [
        migrations.AlterField(
            model_name='link',
            name='target',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='target_link_set', to='topology.Node'),
        ),
    ]
