# Generated by Django 2.2.9 on 2020-01-3 13:52

import jsonfield.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('topology', '0006_reformat_addresses'),
    ]

    operations = [
        migrations.RenameField(
            model_name='node',
            old_name='addresses',
            new_name='addresses_old',
        ),
        migrations.AddField(
            model_name='node',
            name='addresses',
            field=jsonfield.fields.JSONField(default=[]),
        ),
    ]
